import requests
import json

class charSearch:
    def __init__(self, sQ):
        query = '''
        query ($sQ: String) {
        Page(page: 1, perPage: 8){
                characters(search: $sQ){
                    name {
                    full
                    native
                    }
                id
            }    
            }

        }
        '''


        variables = {
            'sQ': sQ
        }

        url = 'https://graphql.anilist.co'

        response = requests.post(url, json={'query': query, 'variables': variables})
        raw = json.loads(response.text)
        self.media = raw["data"]["Page"]["characters"]
    def result(self):
        return self.media
    def name(self, resultnumber: int):
        return self.media[resultnumber]["name"]["full"]
    def id(self, resultnumber: int):
        return self.media[resultnumber]["id"]



from anilistpy.anime import Anime
from anilistpy.manga import Manga
from anilistpy.search.manga import mangaSearch
from anilistpy.search.anime import animeSearch
from anilistpy.search.char import charSearch
from anilistpy.utils import videoLink

'''
    easy to use wrapper for anilist apiv2
    Copyright (C) 2020  0kalekale

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
'''